using System;
using System.Windows.Forms;
using System.Collections.Generic;
using System.Linq;

class Script
{
	[STAThread]
	static public void Main(string[] args)
	{
		var allFiles = System.IO.Directory.GetFiles(".", "*", System.IO.SearchOption.AllDirectories);
		var badFiles = from file in allFiles where !AsciiOnly(file) select file;
		var unexpected = from file in badFiles where !file.Contains("karh.free.fr") select file;
		var textFiles = from file in allFiles
						where
							file.EndsWith(".htm", StringComparison.InvariantCultureIgnoreCase) ||
							file.EndsWith(".html", StringComparison.InvariantCultureIgnoreCase) ||
							file.EndsWith(".xml", StringComparison.InvariantCultureIgnoreCase)
						select file;

		//rename all files to ascii

		foreach (var file in badFiles)
		{
			Dictionary<string, string> patterns = new Dictionary<string, string>() {
			{@"(p)([^a-z0-1 ]+?)(tain)","$1e$3"},
			{@"(pr)([^a-z0-1 ]+?)(sentation)","$1e$3"},
			{@"(panique )([^a-z0-1 ]+?)( beverly)","$1a$3"},
			{@"(po)([^a-z0-1 ]+?)(te)","$1e$3"},
			};
			string newName = file;
			for (int i = 0; i < patterns.Count; i++)
			{
				var key = patterns.Keys.ElementAt(i);
				newName = System.Text.RegularExpressions.Regex.Replace(newName, key, patterns[key], System.Text.RegularExpressions.RegexOptions.IgnoreCase);
			}
			Console.WriteLine(newName);
#if !DEBUG
			System.IO.Directory.CreateDirectory(System.IO.Path.GetDirectoryName(newName));
			System.IO.File.Move(file, newName);
#endif
		}

		//correct all links
		//pattern:
		//src="Blog%20de%20Leo/P%c3%a9tain%20et%20Gandhi/ap%c3%a9tain%20et%20gandhi%20pr%c3%a9sentation%202.jpg"
		//match (%[0-9A-Fa-f]{2})
		//p(__match__+?)tain => petain
		//pr()sentation => presentation
		//panique()beverly => panique a beverly
		//po()te => poete

		foreach (var file in textFiles)
		{
			string content = System.IO.File.ReadAllText(file);
			string result = content;
			Dictionary<string, string> patterns = new Dictionary<string, string>() {
			{@"(?<=src\s*?=\s*?""[^""]*?)(p)((?:%[0-9a-f]{2})+?)(tain)(?=.*?"")","$1e$3"},
			{@"(?<=src\s*?=\s*?""[^""]*?)(pr)((?:%[0-9a-f]{2})+?)(sentation)(?=.*?"")","$1e$3"},
			{@"(?<=src\s*?=\s*?""[^""]*?)(panique%20)((?:%[0-9a-f]{2})+?)(%20beverly)(?=.*?"")","$1a$3"},
			{@"(?<=src\s*?=\s*?""[^""]*?)(po)((?:%[0-9a-f]{2})+?)(te)(?=.*?"")","$1e$3"},
			};
			for (int i = 0; i < patterns.Count; i++)
			{
				var key = patterns.Keys.ElementAt(i);
				result = System.Text.RegularExpressions.Regex.Replace(result, key, patterns[key], System.Text.RegularExpressions.RegexOptions.IgnoreCase);
			}
			if (result != content)
			{
#if !DEBUG
				System.IO.File.WriteAllText(file, result);
#endif
			}
		}
	}

	static private bool AsciiOnly(string filename)
	{
		foreach (char character in filename)
		{
			if (character > 127)
			{
				return false;
			}
		}
		return true;
	}
}

